==> aliyun-python-sdk-onsmqtt-1.0.4.tar.gz: aliyun-python-sdk-onsmqtt-1.0.4/aliyunsdkonsmqtt/request/v20200420/BatchQuerySessionByClientIdsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkonsmqtt.endpoint import endpoint_data

class BatchQuerySessionByClientIdsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'OnsMqtt', '2020-04-20', 'BatchQuerySessionByClientIds','onsmqtt')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ClientIdLists(self):
		return self.get_query_params().get('ClientIdLists')

	def set_ClientIdLists(self, ClientIdLists):
		for depth1 in range(len(ClientIdLists)):
			if ClientIdLists[depth1] is not None:
				self.add_query_param('ClientIdList.' + str(depth1 + 1) , ClientIdLists[depth1])

	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)

==> aliyun-python-sdk-onsmqtt-1.0.5.tar.gz: aliyun-python-sdk-onsmqtt-1.0.5/aliyunsdkonsmqtt/request/v20200420/BatchQuerySessionByClientIdsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkonsmqtt.endpoint import endpoint_data

class BatchQuerySessionByClientIdsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'OnsMqtt', '2020-04-20', 'BatchQuerySessionByClientIds','onsmqtt')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ClientIdLists(self):
		return self.get_query_params().get('ClientIdList')

	def set_ClientIdLists(self, ClientIdLists):
		for depth1 in range(len(ClientIdLists)):
			if ClientIdLists[depth1] is not None:
				self.add_query_param('ClientIdList.' + str(depth1 + 1) , ClientIdLists[depth1])

	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)
